# vim: expandtab tabstop=4 shiftwidth=4

from pathlib import Path
from random import choice
from string import ascii_letters, digits
from tempfile import gettempdir

def make_rand_name(length: int=15) -> str:
    '''
    Returns a random string of alphanumeric characters.
    Always starts with a letter, not a number.
    '''
    return choice(ascii_letters) + ''.join([choice(ascii_letters+digits) for i in range(length-1)])

def TemporaryPath() -> Path:
    '''
    Returns a pathlib.Path in the system-defined temporary directory.
    '''
    return Path(gettempdir()).joinpath(make_rand_name())

# The original implementation attempted to make TemporaryPath and
# TemporaryPathContext one and the same, but it turns out that
# pathlib.Path is difficult to subclass in a sustainable way.

class TemporaryPathContext:
    '''
    Context manager that provides a TemporaryPath then deletes it
    once the context ends.
    '''
    def __enter__(self) -> Path:
        self.path = TemporaryPath()  # pylint: disable=W0201
        self.path.touch()
        return self.path

    def __exit__(self, exc_type, exc_value, exc_traceback) -> None:
        self.path.unlink()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['temppath']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'temppath',
    'version': '2021.236.907',
    'description': 'A quick way to get a temporary pathlib.Path.',
    'long_description': "# temppath\n\nProvides a quick way to get a `pathlib.Path` file in the system-defined\ntemporary space.  `temppath` does _not_ wrap `tempfile.NamedTemporaryFile`,\nas that automatically deletes on close, and does not allow the same file to be\nwritten, closed, then read [in Windows](https://docs.python.org/3/library/tempfile.html#tempfile.NamedTemporaryFile),\nwhich is inconsistent with the Unix implementation.  Since `temppath`\nprovides `pathlib.Path` objects, this is not an issue.\n\n## Usage\n\nThere is a nice context manager, which will remove the path for you.\n\n```python\nfrom temppath import TemporaryPathContext\n\nwith TemporaryPathContext() as t:\n    t.write_text('the quick brown fox jumps over the lazy dog')\n    ...\n    do_something_awesome_that_reads(t)\n\n# The file is removed when you leave the `with` context.\n```\n\nYou also have the option to just clean it up yourself if you need more control.\n\n```python\nfrom temppath import TemporaryPath\n\nt = TemporaryPath()\nt.write_text('the quick brown fox jumps over the lazy dog')\n...\ndo_something_awesome_that_reads(t)\n...\nt.unlink()\n```\n",
    'author': 'Bill Allen',
    'author_email': 'billallen256@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'http://github.com/billallen256/temppath',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.4',
}


setup(**setup_kwargs)
